|Emmental|
==========

|CI-CD| |CodeClimate| |Coveralls| |ReadTheDocs| |PyPI| |PyPIVersion| |GitHubStars| |License| |CodeStyle|

Emmental is a framework for building multi-modal multi-task learning systems.

Note that Emmental is still *actively under development*, so feedback and
contributions are welcome. Submit bugs in the Issues_ section or feel free to
submit your contributions as a pull request.

Getting Started
---------------

Check out our `Getting Started Guide`_ to get up and running with Emmental.

Learning how to use Emmental
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The `Emmental tutorials`_ cover the Emmental workflow, showing how to build
multi-modal multi-task learning systems.

Reference
---------

`Emmental: A framework for building multi-modal multi-task learning systems`::

    @misc{wu2019emmental,
      title={Emmental: A framework for building multi-modal multi-task learning systems},
      author={Wu, Sen},
      year={2019},
    }


.. |Emmental| image:: docs/static/img/emmental-logo.png
   :target: https://github.com/SenWu/emmental
.. |CodeClimate| image:: https://img.shields.io/codeclimate/maintainability/SenWu/emmental.svg
   :alt: Code Climate
   :target: https://codeclimate.com/github/SenWu/emmental
.. |CI-CD| image:: https://img.shields.io/github/workflow/status/SenWu/emmental/ci.svg
    :target: https://github.com/SenWu/emmental/actions
.. |Coveralls| image:: https://img.shields.io/coveralls/github/SenWu/emmental.svg
   :target: https://coveralls.io/github/SenWu/emmental
.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/emmental.svg
   :target: https://emmental.readthedocs.io/
.. |PyPI| image:: https://img.shields.io/pypi/v/emmental.svg
   :target: https://pypi.org/project/emmental/
.. |PyPIVersion| image:: https://img.shields.io/pypi/pyversions/emmental.svg
   :target: https://pypi.org/project/emmental/
.. |GitHubStars| image:: https://img.shields.io/github/stars/SenWu/emmental.svg
   :target: https://github.com/SenWu/emmental/stargazers
.. |License| image:: https://img.shields.io/github/license/SenWu/emmental.svg
   :target: https://github.com/SenWu/emmental/blob/master/LICENSE
.. |CodeStyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black

.. _Getting Started Guide: https://emmental.readthedocs.io/en/latest/user/getting_started.html
.. _Emmental tutorials: https://github.com/SenWu/emmental-tutorials
.. _Issues: https://github.com/SenWu/emmental/issues/
